@@ -47,7 +47,7 @@ class DataFile(object):
                 self.type = 'MultiFLEXX'
             else:
                 raise AttributeError('File is not of type nxs or hdf.')
-            self.name = fileLocation.split('/')[-1]
+            self.name = os.path.basename(fileLocation)
             self.fileLocation = os.path.abspath(fileLocation)		
 			
             if not self.type == 'MultiFLEXX':
@@ -127,8 +127,8 @@ class DataFile(object):
                     for att,value in zip(attributes,values):
                         setattr(self,value,np.array(f.get('entry/CAMEA/analyzer/{}'.format(att))))
                     self.analyzerType = np.array(f.get('entry/CAMEA/analyzer/type'))[0]
-                    self.analyzerSelection = np.array(f.get('entry/CAMEA/analyzer/analyzer_selection'))
-                    self.detectorSelection = np.array(f.get('entry/CAMEA/detector/detector_selection'))
+                    self.analyzerSelection = int(np.array(f.get('entry/CAMEA/analyzer/analyzer_selection'))[0])
+                    self.detectorSelection = int(np.array(f.get('entry/CAMEA/detector/detector_selection'))[0])
 
                     instr = getInstrument(f)
                     self.instrument = instr.name.split('/')[-1]
@@ -618,10 +618,10 @@ class DataFile(object):
         
         self.loadBinning(binning)
         
-        EfNormalization = self.instrumentCalibrationEf
-        A4Normalization = self.instrumentCalibrationA4#np.array(instrument.get('calib{}/a4offset'.format(str(binning))))
-        EdgesNormalization = self.instrumentCalibrationEdges#np.array(instrument.get('calib{}/boundaries'.format(str(binning))))
-        Data = self.I#np.array(instrument.get('detector/data'))
+        EfNormalization = self.instrumentCalibrationEf.copy()
+        A4Normalization = self.instrumentCalibrationA4.copy()#np.array(instrument.get('calib{}/a4offset'.format(str(binning))))
+        EdgesNormalization = self.instrumentCalibrationEdges.copy()#np.array(instrument.get('calib{}/boundaries'.format(str(binning))))
+        Data = self.I.copy()#np.array(instrument.get('detector/data'))
         
 
         detectors = Data.shape[1]
@@ -1120,6 +1120,7 @@ class DataFile(object):
 
         self.instrumentCalibrations = np.array([c for c in calibrations.values()])
         self.possibleBinnings = np.array(list(calibrations.keys()))
+        self.binning = -1
 
     def saveHDF(self,saveFileName):
         """Save current HDF file object into an HDF file.
